///////////////////////////////////////////////////////////////////////////
// header file: Jet
// 
// Description: 
//  store information about final state jets
//
// Author: Reinhard Schwienhorst
// Date: 10/19/2006
//
// Modifications:
//
//
////////////////////////////////////////////////////////////////////////////
#ifndef jet_h
#define jet_h

#include "single_top_analysis/Particle.hpp"
#include "single_top_analysis/EventTree.hpp"
//

class Jet: public Particle
{
 public:
  // default constructor
  Jet();
  // default constructor
  Jet(const Jet& other);

  // constructor with existing particle
  Jet(const Particle& other);

  //destructor
  ~Jet();

  // clear: set all contents to their defaults
  inline void Clear() { Particle::Clear(); _EtEM0=0.; };

  // Fill the jet from an EventTree
  void Fill(EventTree *evtr,int iE);

  // Setters
  // Set E over P for this jet
  void SetEtEM0(const double& eop) { _EtEM0=eop; };

  // Getters
  double GetEtEM0() const { return _EtEM0; };
  double EtEM0() const { return _EtEM0; };


  // overloaded operators:
  // +=
  Jet& operator+=(const Jet& other);
  // addition:
  Jet operator+(const Jet& other);
  // overloaded assignment operator:
  Jet& operator=(const Particle& other);
  // overloaded assignment operator:
  Jet& operator=(const Jet& other);
  // overloaded assignment operator:
  Jet& operator=(Jet& other);
    

 private:
  double _EtEM0;   // calo energy in first EM layer

  ////////////////////////////////////////
  // needed to run with Root:
  ClassDef(Jet,0)
};


#endif
