//////////////////////////////////////////////////////////////////
//
// file: Electrons.cpp
// Description: Create a container for an electron. 
//
// Author: Reinhard Schwienhorst
// Created: 10/19/2006
//
// Modifications:
//
//
//////////////////////////////////////////////////////////////////
#include "single_top_analysis/Electron.hpp"
#include <iostream>
#include <string>
#include <fstream>


using namespace std;

// needed to run with compiled Root:
ClassImp(Electron)

//-------------------------------------------------------------------------
// default constructor 
// 
  Electron::Electron() : Particle::Particle(),_EoverP(0.)
{
}

//-------------------------------------------------------------------------
// default destructor 
// 
Electron::~Electron()
{
  //cout<<"In electron destructor"<<endl;
}

//-------------------------------------------------------------------------
// constructor from other electron 
// 
Electron::Electron(const Electron& other): Particle(other),_EoverP(other.EoverP())
{
}

//-------------------------------------------------------------------------
// constructor from other particle
// 
Electron::Electron(const Particle& other): Particle(other),_EoverP(0.)
{
}

//-------------------------------------------------------------------------
// operator overloading
// 
// +=
Electron& Electron::operator+=(const Electron& other)
{
  
  Particle::operator+=(other);
  // also add EoverPs
  SetEoverP(EoverP()+other.EoverP());
  return *this;
}

//-------------------------------------------------------------------------
// 
// addition operator overloading
Electron Electron::operator+(const Electron& other)
{
  //cout<<"beginning of  Electron::operator+"<<endl;
  Particle tltemp=Particle::operator+(other);
  Electron ptemp=tltemp;
  
  // I don't know how to add the EoverP for two different electrons.
  // For now, add the energies and add the momenta and then divide.
  Double_t EoP=0.;
  Double_t E1=E(), E2=other.E();
  Double_t Ptot=0.;
 
  if(EoverP()!=0.) Ptot=E()/EoverP();
  else E1=0.;

  if(other.EoverP()!=0.) Ptot += other.E()/other.EoverP();
  else E2=0.;

  if(Ptot==0.) _EoverP=0.;
  else _EoverP = (E1+E2) / Ptot;

  ptemp.SetEoverP( _EoverP );

  // done! return the temp particle
  //cout<<"returning from  Electron::operator+"<<endl;
  return ptemp;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another electron
// 
Electron& Electron::operator=(const Particle& other)
{
  
  Particle::operator=(other);
  SetEoverP(0.);
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another Electron
// (const version)
Electron& Electron::operator=(const Electron& other)
{
  
  Particle::operator=(other);
  SetEoverP(other.EoverP());
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another Electron
// (non-const version)
Electron& Electron::operator=(Electron& other)
{
  
  Particle::operator=(other);
  SetEoverP(other.EoverP());
  return *this;
}

//-------------------------------------------------------------------------
// initialize this electron from the event tree
// 
void Electron::Fill(EventTree *evtr,int iE)
{

    Double_t elPt  = evtr->El_p_T->operator[](iE)/1000.;
    Double_t elEta = evtr->El_eta->operator[](iE);
    Double_t elPhi = evtr->El_phi->operator[](iE);
    Double_t elE   = evtr->El_E->operator[](iE);
    _EoverP        = evtr->El_EoverP->operator[](iE);
    Double_t elCharge= evtr->El_charge->operator[](iE);

    SetPtEtaPhiE(elPt,elEta,elPhi,elE);
    SetCharge(elCharge);

}


