//////////////////////////////////////////////////////////////////
//
// file: Jets.cpp
// Description: Create a container for an jet. 
//
// Author: Reinhard Schwienhorst
// Created: 11/14/2006
//
// Modifications:
//
//
//////////////////////////////////////////////////////////////////
#include "single_top_analysis/Jet.hpp"
#include <iostream>
#include <string>
#include <fstream>


using namespace std;

// needed to run with compiled Root:
ClassImp(Jet)

//-------------------------------------------------------------------------
// default constructor 
// 
  Jet::Jet() : Particle::Particle(),_EtEM0(0.)
{
}

//-------------------------------------------------------------------------
// default destructor 
// 
Jet::~Jet()
{
  //cout<<"In jet destructor"<<endl;
}

//-------------------------------------------------------------------------
// constructor from other jet 
// 
Jet::Jet(const Jet& other): Particle(other),_EtEM0(other.EtEM0())
{
}

//-------------------------------------------------------------------------
// constructor from other particle
// 
Jet::Jet(const Particle& other): Particle(other),_EtEM0(0.)
{
}

//-------------------------------------------------------------------------
// operator overloading
// 
// +=
Jet& Jet::operator+=(const Jet& other)
{
  
  Particle::operator+=(other);
  // also add EtEM0s
  SetEtEM0(EtEM0()+other.EtEM0());
  return *this;
}

//-------------------------------------------------------------------------
// 
// addition operator overloading
Jet Jet::operator+(const Jet& other)
{
  //cout<<"beginning of  Jet::operator+"<<endl;
  Particle tltemp=Particle::operator+(other);
  Jet ptemp=tltemp;
  
  // I don't know how to add the EtEM0 for two different jets.
  // For now, add them.
  _EtEM0 += other.EtEM0();

  ptemp.SetEtEM0( _EtEM0 );

  // done! return the temp particle
  //cout<<"returning from  Jet::operator+"<<endl;
  return ptemp;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another jet
// 
Jet& Jet::operator=(const Particle& other)
{
  
  Particle::operator=(other);
  SetEtEM0(0.);
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another Jet
// (const version)
Jet& Jet::operator=(const Jet& other)
{
  
  Particle::operator=(other);
  SetEtEM0(other.EtEM0());
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another Jet
// (non-const version)
Jet& Jet::operator=(Jet& other)
{
  
  Particle::operator=(other);
  SetEtEM0(other.EtEM0());
  return *this;
}

//-------------------------------------------------------------------------
// initialize this jet from the event tree
// 
void Jet::Fill(EventTree *evtr,int iE)
{

    Double_t jetPt  = evtr->PJet_p_T->operator[](iE)/1000.;
    Double_t jetEta = evtr->PJet_eta->operator[](iE);
    Double_t jetPhi = evtr->PJet_phi->operator[](iE);
    Double_t jetE   = evtr->PJet_E->operator[](iE);
    _EtEM0        = evtr->PJet_etEM0->operator[](iE)/1000.;
    Double_t jetCharge= evtr->PJet_charge->operator[](iE);

    SetPtEtaPhiE(jetPt,jetEta,jetPhi,jetE);
    SetCharge(jetCharge);

}


