//////////////////////////////////////////////////////////////////
//
// file: MCElectron.cpp
// Description: Create a container for an MCelectron. 
//
// Author: Reinhard Schwienhorst
// Created: 11/15/2006
//
// Modifications:
//
//
//////////////////////////////////////////////////////////////////
#include "single_top_analysis/MCElectron.hpp"
#include <iostream>
#include <string>
#include <fstream>


using namespace std;

// needed to run with compiled Root:
ClassImp(MCElectron)

//-------------------------------------------------------------------------
// default constructor 
// 
  MCElectron::MCElectron() : MCParticle::MCParticle(), _EoverP(0.)
{
}

//-------------------------------------------------------------------------
// default destructor 
// 
MCElectron::~MCElectron()
{
  //cout<<"In MCelectron destructor"<<endl;
}

//-------------------------------------------------------------------------
// constructor from other particle 
// 
MCElectron::MCElectron(const MCElectron& other): MCParticle(other),_EoverP(other.EoverP())
{
}

//-------------------------------------------------------------------------
// constructor from other TLorentzVector
// 
MCElectron::MCElectron(const MCParticle& other): MCParticle(other),_EoverP(0.)
{
}

//-------------------------------------------------------------------------
// operator overloading
// 
// +=
MCElectron& MCElectron::operator+=(const MCElectron& other)
{
  
  MCParticle::operator+=(other);
  // also add EoverPs
  SetEoverP(EoverP()+other.EoverP());
  return *this;
}

//-------------------------------------------------------------------------
// 
// addition operator overloading
MCElectron MCElectron::operator+(const MCElectron& other)
{
  //cout<<"beginning of  MCElectron::operator+"<<endl;
  MCParticle tltemp=MCParticle::operator+(other);
  MCElectron ptemp=tltemp;
  
  // I don't know how to add the EoverP for two different MCelectrons.
  // For now, add the energies and add the momenta and then divide.
  Double_t EoP=0.;
  Double_t E1=E(), E2=other.E();
  Double_t Ptot=0.;
 
  if(EoverP()!=0.) Ptot=E()/EoverP();
  else E1=0.;

  if(other.EoverP()!=0.) Ptot += other.E()/other.EoverP();
  else E2=0.;

  if(Ptot==0.) _EoverP=0.;
  else _EoverP = (E1+E2) / Ptot;

  ptemp.SetEoverP( _EoverP );

  // done! return the temp particle
  //cout<<"returning from  MCElectron::operator+"<<endl;
  return ptemp;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another MCelectron
// 
MCElectron& MCElectron::operator=(const MCParticle& other)
{
  
  MCParticle::operator=(other);
  SetEoverP(0.);
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another MCElectron
// (const version)
MCElectron& MCElectron::operator=(const MCElectron& other)
{
  
  MCParticle::operator=(other);
  SetEoverP(other.EoverP());
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another MCElectron
// (non-const version)
MCElectron& MCElectron::operator=(MCElectron& other)
{
  
  MCParticle::operator=(other);
  SetEoverP(other.EoverP());
  return *this;
}

//-------------------------------------------------------------------------
// initialize this MCelectron from the event tree
// 
void MCElectron::Fill(TruthTree *trtr,int iE)
{

    Double_t elPt  = trtr->El_p_T->operator[](iE)/1000.;
    Double_t elEta = trtr->El_eta->operator[](iE);
    Double_t elPhi = trtr->El_phi->operator[](iE);
    Double_t elE   = trtr->El_E->operator[](iE);
    Int_t elPdgId  = trtr->El_pdgId->operator[](iE);
    Int_t elStat   = trtr->El_status->operator[](iE);
    Int_t elBc     = trtr->El_BarCode->operator[](iE);
    _EoverP        = trtr->El_EoverP->operator[](iE);
    Double_t elCharge= trtr->El_charge->operator[](iE);

    SetPtEtaPhiE(elPt,elEta,elPhi,elE);
    SetCharge(elCharge);
    SetPdgId(elPdgId);
    SetStatus(elStat);
    SetBarCode(elBc);

}


