//////////////////////////////////////////////////////////////////
//
// file: MCParticles.cpp
// Description: Create a container for an MCparticle. 
//
// Author: Reinhard Schwienhorst
// Created: 11/15/2006
//
// Modifications:
//
//
//////////////////////////////////////////////////////////////////
#include "single_top_analysis/MCParticle.hpp"
#include <iostream>
#include <string>
#include <fstream>


using namespace std;

// needed to run with compiled Root:
ClassImp(MCParticle)

//-------------------------------------------------------------------------
// default constructor 
// 
  MCParticle::MCParticle() : Particle::Particle(),_PdgId(0),
					       _Status(0),_BarCode(0)
{
}

//-------------------------------------------------------------------------
// default destructor 
// 
MCParticle::~MCParticle()
{
  //cout<<"In MCparticle destructor"<<endl;
}

//-------------------------------------------------------------------------
// constructor from other MCparticle 
// 
MCParticle::MCParticle(const MCParticle& other): Particle(other),
						 _PdgId(other.PdgId()),_BarCode(other.BarCode()),
						 _Status(other.Status())
{
}

//-------------------------------------------------------------------------
// constructor from other particle
// 
MCParticle::MCParticle(const Particle& other): Particle(other),_PdgId(0),
					       _Status(0),_BarCode(0)
{
}

//-------------------------------------------------------------------------
// operator overloading
// 
// +=
MCParticle& MCParticle::operator+=(const MCParticle& other)
{
  
  Particle::operator+=(other);
  // don't change pdgid or status or stable flags.

  return *this;
}

//-------------------------------------------------------------------------
// 
// addition operator overloading
MCParticle MCParticle::operator+(const MCParticle& other)
{
  //cout<<"beginning of  MCParticle::operator+"<<endl;
  Particle tltemp=Particle::operator+(other);
  MCParticle ptemp=tltemp;

  // I don't know how to add PDG IDs or flags, so for now simply don't modify
  // anything from the first one.
  ptemp.SetPdgId( _PdgId );
  ptemp.SetStatus( _Status );
  ptemp.SetBarCode( _BarCode );


  // done! return the temp particle
  //cout<<"returning from  MCParticle::operator+"<<endl;
  return ptemp;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another MCparticle
// 
MCParticle& MCParticle::operator=(const Particle& other)
{
  
  Particle::operator=(other);
  SetPdgId(0);
  SetStatus(0);
  SetBarCode(0);
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another MCParticle
// (const version)
MCParticle& MCParticle::operator=(const MCParticle& other)
{
  
  Particle::operator=(other);
  SetPdgId(other.PdgId());
  SetStatus(other.Status());
  SetBarCode(other.BarCode());
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another MCParticle
// (non-const version)
MCParticle& MCParticle::operator=(MCParticle& other)
{
  
  Particle::operator=(other);
  SetPdgId(other.PdgId());
  SetStatus(other.Status());
  SetBarCode(other.BarCode());
  return *this;
}

//-------------------------------------------------------------------------
// initialize this MCparticle from the truth tree
// 
void MCParticle::Fill(TruthTree *trtr,int iE)
{

    Double_t pPt  = trtr->Truth_p_T->operator[](iE)/1000.;
    Double_t pEta = trtr->Truth_eta->operator[](iE);
    Double_t pPhi = trtr->Truth_phi->operator[](iE);
    Double_t pM   = trtr->Truth_m->operator[](iE)/1000.;
    Double_t pCharge= trtr->Truth_charge->operator[](iE);

    _PdgId = trtr->Truth_pdgId->operator[](iE);
    _Status= trtr->Truth_status->operator[](iE);
    _BarCode= trtr->Truth_BarCode->operator[](iE);

    SetPtEtaPhiM(pPt,pEta,pPhi,pM);
    SetCharge(pCharge);

}



