//////////////////////////////////////////////////////////////////
//
// file: Muons.cpp
// Description: Create a container for an muon. 
//
// Author: Reinhard Schwienhorst
// Created: 11/14/2006
//
// Modifications:
//
//
//////////////////////////////////////////////////////////////////
#include "single_top_analysis/Muon.hpp"
#include <iostream>
#include <string>
#include <fstream>


using namespace std;

// needed to run with compiled Root:
ClassImp(Muon)

//-------------------------------------------------------------------------
// default constructor 
// 
  Muon::Muon() : Particle::Particle(),_EtCone(0.)
{
}

//-------------------------------------------------------------------------
// default destructor 
// 
Muon::~Muon()
{
  //cout<<"In muon destructor"<<endl;
}

//-------------------------------------------------------------------------
// constructor from other muon 
// 
Muon::Muon(const Muon& other): Particle(other),_EtCone(other.EtCone())
{
}

//-------------------------------------------------------------------------
// constructor from other particle
// 
Muon::Muon(const Particle& other): Particle(other),_EtCone(0.)
{
}

//-------------------------------------------------------------------------
// operator overloading
// 
// +=
Muon& Muon::operator+=(const Muon& other)
{
  
  Particle::operator+=(other);
  // also add EtCones
  SetEtCone(EtCone()+other.EtCone());
  return *this;
}

//-------------------------------------------------------------------------
// 
// addition operator overloading
Muon Muon::operator+(const Muon& other)
{
  //cout<<"beginning of  Muon::operator+"<<endl;
  Particle tltemp=Particle::operator+(other);
  Muon ptemp=tltemp;

  // I don't know how to add the EtCone for two different muons.
  // for now simply add them
  _EtCone += other.EtCone();

  ptemp.SetEtCone( _EtCone );

  // done! return the temp particle
  //cout<<"returning from  Muon::operator+"<<endl;
  return ptemp;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another muon
// 
Muon& Muon::operator=(const Particle& other)
{
  
  Particle::operator=(other);
  SetEtCone(0.);
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another Muon
// (const version)
Muon& Muon::operator=(const Muon& other)
{
  
  Particle::operator=(other);
  SetEtCone(other.EtCone());
  return *this;
}

//-------------------------------------------------------------------------
// assignment operator overloading from another Muon
// (non-const version)
Muon& Muon::operator=(Muon& other)
{
  
  Particle::operator=(other);
  SetEtCone(other.EtCone());
  return *this;
}

//-------------------------------------------------------------------------
// initialize this muon from the event tree
// 
void Muon::Fill(EventTree *evtr,int iE)
{

    Double_t muPt  = evtr->Mu_p_T->operator[](iE)/1000.;
    Double_t muEta = evtr->Mu_eta->operator[](iE);
    Double_t muPhi = evtr->Mu_phi->operator[](iE);
    Double_t muE   = evtr->Mu_E->operator[](iE);
    _EtCone        = evtr->Mu_etcone->operator[](iE)/1000.;
    Double_t muCharge= evtr->Mu_charge->operator[](iE);

    SetPtEtaPhiE(muPt,muEta,muPhi,muE);
    SetCharge(muCharge);

}


