////////////////////////////////////////////////////////////////
//
//  wrapper class for 1d histograms
//
//
#include "single_top_analysis/myTH2F.hpp"
#include "single_top_analysis/EventContainer.hpp"

using namespace std;

//-----------------------------------------------------------------
// Create the same histogram in several different directories
myTH2F::myTH2F(TDirectory *baseDir,EventContainer *obj,const std::string& name, const std::string& title,
	       int nXBins, Double_t xMin, Double_t xMax,
	       int nYBins, Double_t yMin, Double_t yMax): _obj(obj)
{
  //Create directories
  baseDir->cd();
  //// both s- and t-channel
  //if(! baseDir->GetKey("inclusive")) baseDir->mkdir("inclusive");

  //
  // now Create histograms and store pointers to them.
  //baseDir->cd("inclusive");
  _hincl=new TH2F(name.c_str(),title.c_str(),nXBins,xMin,xMax,nYBins,yMin,yMax);  

}

//-----------------------------------------------------------------
// fill each of the histograms
int myTH2F::Fill(Double_t x, Double_t y, Double_t myWeight)
{
  //
  // the weight is given to us by the EventContainer class.
  Double_t weight=_obj->GetEventWeight();

  // if the input weight is greater than 0, use that instead of the 
  // global event weight
  if(myWeight>0.) weight=myWeight;


  _hincl->Fill(x,y,weight);
    
  return 0;
}

//-----------------------------------------------------------------
// fill each of the histograms, but without weight
int myTH2F::FillWithoutWeight(Double_t x, Double_t y)
{
  // always fill the inclusive histogram:
  _hincl->Fill(x,y,1.);
  return 0;
}

//----------------------------------------------------------------
// write histograms to the output file
int myTH2F::Write(TDirectory *baseDir)
{
  // now Create histograms and store pointers to them.
  //baseDir->cd("inclusive");
  _hincl->Write();  
  
  return 0;
}

//----------------------------------------------------------------
// copy the content of this histogram into the other
int myTH2F::Copy(myTH2F other)
{
  // call the copy method for each histogram
  _hincl->Copy(*(other._hincl));  
  
  return 0;
}

//----------------------------------------------------------------
//divide the content of this histogram by the other
int myTH2F::Divide(myTH2F other)
{
  // call the divide method for each histogram
  _hincl->Divide(other._hincl);  
  
  return 0;
}

//----------------------------------------------------------------
// Set the labels for the X axis 
void myTH2F::SetXAxisTitle(TString label)
{
  // call the method for each histogram
  _hincl->GetXaxis()->SetTitle(label);  
  
  return;
}

//----------------------------------------------------------------
// Set the labels for the Y axis 
void myTH2F::SetYAxisTitle(TString label)
{
  // call the method for each histogram
  _hincl->GetYaxis()->SetTitle(label);  
  
  return;
}

//----------------------------------------------------------------
// Set the labels for the X axis bins individually
void myTH2F::SetXAxisBinLabel(Int_t iBin,TString label)
{
  // call the method for each histogram
  // to Set the bin label on the X axis
  _hincl->GetXaxis()->SetBinLabel(iBin,label);  
  
  return;
}

//----------------------------------------------------------------
// Set the labels for the Y axis bins individually
void myTH2F::SetYAxisBinLabel(Int_t iBin,TString label)
{
  // call the method for each histogram
  // to Set the bin label on the Y axis
  _hincl->GetYaxis()->SetBinLabel(iBin,label);  
  
  return;
}
